@@ -29,13 +29,19 @@ def check_file(subdir: str, filename: str, *, data: bool = True) -> None:
         args.mode,
         fast=args.fast,
         minimum_version=args.minimum_version,
+        lines=args.lines,
     )
     if args.minimum_version is not None:
         major, minor = args.minimum_version
         target_version = TargetVersion[f"PY{major}{minor}"]
         mode = replace(args.mode, target_versions={target_version})
         assert_format(
-            source, expected, mode, fast=args.fast, minimum_version=args.minimum_version
+            source,
+            expected,
+            mode,
+            fast=args.fast,
+            minimum_version=args.minimum_version,
+            lines=args.lines,
         )
 
 
@@ -45,6 +51,24 @@ def test_simple_format(filename: str) -> None:
     check_file("cases", filename)
 
 
+@pytest.mark.parametrize("filename", all_data_cases("line_ranges_formatted"))
+def test_line_ranges_line_by_line(filename: str) -> None:
+    args, source, expected = read_data_with_mode("line_ranges_formatted", filename)
+    assert (
+        source == expected
+    ), "Test cases in line_ranges_formatted must already be formatted."
+    line_count = len(source.splitlines())
+    for line in range(1, line_count + 1):
+        assert_format(
+            source,
+            expected,
+            args.mode,
+            fast=args.fast,
+            minimum_version=args.minimum_version,
+            lines=[(line, line)],
+        )
+
+
 # =============== #
 # Unusual cases
 # =============== #
